Skip to contents

Estimate the area under the disease progress curve from only the initial and final observations under a logistic epidemic assumption.

Usage

AUDPC_2_points(time, y0, yT)

Arguments

time

Time elapsed between the two assessments.

y0

Initial disease intensity as a proportion.

yT

Final disease intensity as a proportion.

Value

A numeric scalar with the estimated AUDPC.

References

Jeger, M. J., and Viljanen-Rollinson, S. L. H. (2001). The use of the area under the disease-progress curve (AUDPC) to assess quantitative disease resistance in crop cultivars. Theoretical and Applied Genetics, 102, 32-40.

Examples

epi <- sim_logistic(N = 30, y0 = 0.01, dt = 5, r = 0.3, alpha = 0.5, n = 1)
AUDPC_2_points(time = epi$time[7], y0 = epi$y[1], yT = epi$y[7])
#> [1] 14.68996