Internal helper used by the simulation functions to solve the logistic epidemic model with `deSolve::ode()`: \(dy/dt = r y (1 - y / K)\).
Internal helper used by the simulation functions to solve the logistic epidemic model with `deSolve::ode()`: \(dy/dt = r y (1 - y / K)\).