Skip to contents

Simulate disease progress data under the monomolecular epidemic model, with optional replicated observations.

Usage

sim_monomolecular(N = 10, dt = 1, y0 = 0.01, r, K = 1, n, alpha = 0.2)

Arguments

N

Total epidemic duration.

dt

Time interval between assessments.

y0

Initial disease intensity.

r

Apparent infection rate.

K

Maximum disease intensity.

n

Number of replicated curves.

alpha

Noise level applied to replicated observations.

Value

A data frame with simulated disease progress values and replicated noisy observations.

Examples

sim_monomolecular(N = 30, dt = 5, y0 = 0.01, r = 0.05, K = 1, n = 4)
#>    replicates time         y   random_y
#> 1           1    0 0.0100000 0.01000000
#> 2           1    5 0.2289861 0.27053162
#> 3           1   10 0.3995322 0.31964473
#> 4           1   15 0.5323535 0.50927402
#> 5           1   20 0.6357949 0.58411443
#> 6           1   25 0.7163551 0.68584328
#> 7           1   30 0.7790955 0.85093817
#> 8           2    0 0.0100000 0.01003444
#> 9           2    5 0.2289861 0.18356647
#> 10          2   10 0.3995322 0.32081388
#> 11          2   15 0.5323535 0.55476861
#> 12          2   20 0.6357949 0.63493532
#> 13          2   25 0.7163551 0.70342944
#> 14          2   30 0.7790955 0.74710581
#> 15          3    0 0.0100000 0.01000000
#> 16          3    5 0.2289861 0.19102076
#> 17          3   10 0.3995322 0.44751480
#> 18          3   15 0.5323535 0.50142023
#> 19          3   20 0.6357949 0.57167935
#> 20          3   25 0.7163551 0.79231953
#> 21          3   30 0.7790955 0.79372796
#> 22          4    0 0.0100000 0.01000000
#> 23          4    5 0.2289861 0.26636147
#> 24          4   10 0.3995322 0.44206384
#> 25          4   15 0.5323535 0.50152099
#> 26          4   20 0.6357949 0.73796377
#> 27          4   25 0.7163551 0.70599131
#> 28          4   30 0.7790955 0.73006279